/**
 * Inspired by https://github.com/TheWebSolver/tws-license-manager-client
 */

:root {
    --primary-color: #F48722;
    --primary-focus: #F48722;
    --dark: #263238;
    --dark-gray: #808080;
    --mid-gray: #ccc;
    --light-gray: #eee;
    --error: #404040;
    --white: #fff;
    --light: #eae9e9;
    --warning: #ff8300;
    --shadow-normal: rgba(152, 185, 227, 0.15);
    --shadow-primary: rgba(0, 150, 136, 0.15);
    --shadow-warning: rgba(255, 131, 0, 0.15);
    --shadow-error: rgba(206, 0, 0, 0.15);
}
body {
    background-color: var(--shadow-normal);
}
a {
    text-decoration: none !important;
}
body.active {
    background-color: var(--shadow-primary);
}
body.disabled {
    background-color: var(--shadow-warning);
}
body.expired {
    background-color: var(--shadow-error);
}
.notice {
    padding-top: 10px;
    padding-bottom: 10px;
    margin: 30px auto 15px;
    max-width: 600px;
}
#dlm_license_form {
    padding-right: 20px;
    max-width: 600px;
    margin: 50px auto;
}
.dlm_license_form_content {
    padding: 20px;
    margin-top: 15px;
    background-color: var(--white);
    border-radius: 5px;
    overflow: hidden;
}
.dlm_license_form_content.disabled {
    background-color: var(--light-gray);
}
#dlm_activate_plugin {
    display: flex;
    flex-direction: column;
}
#dlm_activate_plugin div {
    margin-bottom: 15px;
    margin-block-end: 15px;
}
#dlm_activate_plugin p {
    margin-bottom: 0;
    margin-block-end: 0;
}
#dlm_activate_plugin p.label {
    color: var(--dark-gray);
}
#dlm_activate_plugin p.field {
    margin-top: 5px;
    margin-block-start: 5px;
}
#dlm_activate_plugin input, #dlm_activate_plugin select {
    width: 100%;
    min-height: 50px;
    border: 2px solid var(--light);
    border-radius: 5px;
    max-width:100%;
}
.error {
    color: var(--error);
    padding-left: 5px;
    padding-inline-start: 5px;
    margin-top: 3px;
    margin-block-start: 3px;
}

.dlm_license_form_head, #dlm_license_branding, #dlm_license_actions {
    display: flex;
    align-items: center;
    flex-flow: row nowrap;
    margin-top: 20px;
}
#logo {
    margin-right: 10px;
    padding: 10px 0;
}
#logo img {
    max-width: 60px;
}
#dlm_license_status {
    margin-left: auto;
    min-width: 105px;
}
#dlm_license_status span {
    display: block;
    text-align: center;
    font-weight: 600;
}
#dlm_license_status .value {
    padding: 2px 10px;
    border-radius: 999px;
    border: 2px solid var(--dark-gray);
    margin-top: 5px;
    text-transform: capitalize;
}
#dlm_license_status .value.active {
    color: var(--primary-color);
    border-color: var(--primary-color);
}
#dlm_license_status .value.disabled, #dlm_license_status .value.missing_token {
    color: var(--warning);
    border-color: var(--warning);
}
#dlm_license_status .value.expired {
    color: var(--error);
    border-color: var(--error);
}

.dlm_license_links {
    margin-right: auto;
}
.dlm_license_links > a {
    margin-right: 5px;
    display: inline-block;
}
.dlm_license_links a.dashboard,
.dlm_license_links a.dashboard:hover {
    color: var(--dark-gray);
}
.dlm_license_links .activate,
.dlm_license_links .deactivate,
.dlm_license_links .cancel,
.dlm_license_button input.dlm_btn__prim {
    font-weight: 400;
    text-transform: Uppercase;
    font-size:14px;
    letter-spacing: 1px;
}
.dlm_license_button input.dlm_btn__prim,
.dlm_expired_notice,
.dlm_expired_notice a {
    color: var(--white);
}

.dlm_license_button input.dlm_btn__prim,
.dlm_expired_notice a {
    border-radius: 50px;
    line-height: 1em !important;
    padding: 15px 30px !important;
    border: none;
    cursor: pointer;
}
fieldset:disabled input.dlm_btn__prim:disabled {
    color: var(--mid-gray);
}

.dlm_license_button {
    margin-bottom: 1em;
    margin-block-end: 1em;
}

.dlm_license_button input.dlm_lmac_btn {
    background: var(--primary-color);
}
.dlm_license_button input.dlm_lmdac_btn,
.dlm_expired_notice {
    background: var(--error);
}
fieldset:disabled input,
fieldset:disabled input.dlm_btn__prim:disabled {
    background-color: var(--light);
    cursor: not-allowed;
}
.dlm_license_form_content,
fieldset input,
.dlm_license_button input.dlm_lmac_btn,
.dlm_license_button input.dlm_lmdac_btn,
.dlm_expired_notice a {
    transition: background-color 0.4s ease-in-out !important;
}
.dlm_expired_notice {
    padding: 10px 20px 20px;
    margin-bottom: -25px;
    border-top-left-radius: 5px;
    border-top-right-radius: 5px;
    font-weight: bold;
    display: flex;
    flex-wrap: nowrap;
    align-items: center;
}
.dlm_expired_notice p:first-of-type {
    margin-right: 15px;
}
.dlm_expired_notice p:last-of-type {
    margin-left: auto;
}
.dlm_expired_notice a {
    display: inline-block;
    min-width: 78px;
    background-color: var(--shadow-primary);
}
.dlm_expired_notice a:hover {
    background-color: var(--shadow-warning);
}
fieldset.dlm_switcher_control {
    font-weight: bold;
    position: relative;
    margin: -20px -20px auto;
    padding: 20px;
    background-color: var(--shadow-normal);
}
fieldset.dlm_switcher_control label {
    display: inline-block;
    max-width: calc(100% - 60px);
}
.dlm_switcher_control input {
    border: none;
    background: transparent;
    color: transparent;
    box-shadow: none;
    width: 0;
    min-width: 0;
    flex-basis: auto;
}
.dlm_switcher_control input:before {
    background: var(--light-gray);
    box-shadow: inset 0px 0px 10px var(--dark);
    border-radius: 8px;
    content: '';
    right: 15px;
    height: 16px;
    margin: 0 !important;
    position: absolute;
    opacity: 0.3 !important;
    transition: all 0.4s ease-in-out;
    width: 40px !important;
}
.dlm_switcher_control input:before,
.dlm_switcher_control input:after {
    top: 50%;
    transform: translateY(-50%);
}
.dlm_switcher_control input:after {
    background: var(--mid-gray);
    border-radius: 16px;
    box-shadow: 0px 0px 5px var(--shadow-normal);
    content: '';
    height: 24px;
    right: 32px;
    position: absolute;
    /* transform: translateY(-20%); */
    transition: all 0.3s ease-in-out, translate 0.3s ease-in-out;
    width: 24px;
}
.dlm_switcher_control input {
    color: transparent;
}
.dlm_switcher_control input:checked:before {
    background: var(--primary-focus);
    opacity: 0.5;
}
.dlm_switcher_control input:checked:after {
    background: var(--primary-color);
    right: 15px;
}
.dlm_switcher_control input:focus:before {
    background: var(--primary-color);
}
.rtl div.dlm_license_form_head, .rtl #dlm_license_branding, .rtl #dlm_license_actions{
    flex-flow: row-reverse;
}

.dlm-license-faq {
    padding: 18px 20px;
    background: var(--white);
    border-radius: 10px;
    box-shadow: 0 6px 22px rgba(38, 50, 56, 0.08);
}

.dlm-license-faq-wrap {
    margin-top: 16px;
}

.dlm-license-faq h3 {
    margin: 0 0 14px;
    font-size: 20px;
    line-height: 1.4;
    text-align: start;
}

.dlm-license-faq-item {
    background: #f8f8f8;
    border: 1px solid #e4e4e4;
    border-radius: 8px;
    padding: 10px 12px;
    margin-bottom: 10px;
}

.dlm-license-faq-item summary {
    position: relative;
    display: flex;
    align-items: center;
    gap: 8px;
    font-weight: 600;
    cursor: pointer;
    text-align: start;
    list-style: none;
}

.dlm-license-faq-item summary::-webkit-details-marker {
    display: none;
}

.dlm-license-faq-item summary::before {
    content: "\f348";
    display: inline-block;
    font-family: dashicons;
    font-size: 16px;
    color: #2271b1;
    line-height: 1;
    flex: 0 0 auto;
}

.dlm-license-faq-item summary::after {
    content: "\f347";
    display: inline-block;
    font-family: dashicons;
    font-size: 16px;
    color: #6b7280;
    line-height: 1;
    margin-inline-start: auto;
    transition: transform 0.2s ease-in-out;
}

.dlm-license-faq-item[open] summary::after {
    transform: rotate(180deg);
}

.dlm-license-faq-item p {
    margin: 10px 0 0;
    color: #444;
    line-height: 1.6;
    text-align: start;
}

.dlm-license-faq-item p a {
    color: var(--primary-color);
    text-decoration: underline !important;
}

.dlm-license-faq-item p a:hover {
    color: #d86f12;
}

.rtl .dlm-license-faq-item summary {
    flex-direction: row-reverse;
}

.rtl .dlm-license-faq-item summary::after {
    margin-inline-start: 0;
    margin-inline-end: auto;
}

.dlm-inline-alert {
    display: flex;
    align-items: flex-start;
    gap: 10px;
    margin: 0 0 16px;
    padding: 12px 14px;
    border-radius: 8px;
    border: 1px solid transparent;
}

.dlm-inline-alert p {
    margin: 0;
    font-weight: 600;
    line-height: 1.45;
}

.dlm-inline-alert__icon {
    font-size: 18px;
    width: 18px;
    height: 18px;
    margin-top: 1px;
}

.dlm-inline-alert--error {
    background: #fff3f1;
    border-color: #f0c6bf;
    color: #7a2316;
}

.dlm-inline-alert--success {
    background: #edf8ef;
    border-color: #b7ddbe;
    color: #1d5b2a;
}

.dlm-license-debug {
    margin: 12px 0 16px;
    padding: 10px 12px;
    background: #f6f7f7;
    border: 1px solid #c3c4c7;
    border-radius: 4px;
    font-size: 13px;
}

.dlm-license-debug summary {
    cursor: pointer;
    font-weight: 600;
    color: #1d2327;
}

.dlm-license-debug__hint {
    margin: 8px 0 6px;
    color: #50575e;
    line-height: 1.5;
}

.dlm-license-debug__pre {
    margin: 0;
    padding: 10px;
    max-height: 320px;
    overflow: auto;
    background: #1d2327;
    color: #f0f0f1;
    border-radius: 4px;
    font-size: 12px;
    line-height: 1.45;
    white-space: pre-wrap;
    word-break: break-word;
}