<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit5971dc4cd2e0482a408417f1d0e5ef7d
{
    public static $prefixLengthsPsr4 = array (
        'I' => 
        array (
            'IdeoLogix\\DigitalLicenseManagerSimpleChecker\\' => 45,
            'IdeoLogix\\DigitalLicenseManagerClient\\' => 38,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'IdeoLogix\\DigitalLicenseManagerSimpleChecker\\' => 
        array (
            0 => __DIR__ . '/..' . '/ideologix/dlm-wp-simple-checker/src',
        ),
        'IdeoLogix\\DigitalLicenseManagerClient\\' => 
        array (
            0 => __DIR__ . '/..' . '/ideologix/dlm-php/src',
        ),
    );

    public static $classMap = array (
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInit5971dc4cd2e0482a408417f1d0e5ef7d::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInit5971dc4cd2e0482a408417f1d0e5ef7d::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInit5971dc4cd2e0482a408417f1d0e5ef7d::$classMap;

        }, null, ClassLoader::class);
    }
}
