<?php

// autoload_psr4.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname($vendorDir);

return array(
    'IdeoLogix\\DigitalLicenseManagerSimpleChecker\\' => array($vendorDir . '/ideologix/dlm-wp-simple-checker/src'),
    'IdeoLogix\\DigitalLicenseManagerClient\\' => array($vendorDir . '/ideologix/dlm-php/src'),
);
