<?php
return ['project-id-version'=>'Maspik - Spam blacklist','report-msgid-bugs-to'=>'','pot-creation-date'=>'2024-02-22 02:13+0000','po-revision-date'=>'2024-08-23 07:47+0000','last-translator'=>'','language-team'=>'French (France)','language'=>'fr_FR','plural-forms'=>'nplurals=2; plural=n > 1;','mime-version'=>'1.0','content-type'=>'text/plain; charset=UTF-8','content-transfer-encoding'=>'8bit','x-generator'=>'Loco https://localise.biz/','x-loco-version'=>'2.6.11; wp-6.6','x-domain'=>'contact-forms-anti-spam','messages'=>['Allow'=>'Permettre']];
