<?php
return ['project-id-version'=>'Maspik - Spam blacklist','report-msgid-bugs-to'=>'','pot-creation-date'=>'2022-04-05 03:38+0000','po-revision-date'=>'2024-08-23 09:57+0000','last-translator'=>'Елена Олеговна','language-team'=>'Russian','language'=>'ru_RU','plural-forms'=>'nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10 >= 2 && n%10<=4 &&(n%100<10||n%100 >= 20)? 1 : 2);','mime-version'=>'1.0','content-type'=>'text/plain; charset=UTF-8','content-transfer-encoding'=>'8bit','x-generator'=>'Loco https://localise.biz/','x-loco-version'=>'2.6.4; wp-6.2.2','x-domain'=>'contact-forms-anti-spam','messages'=>['Arabic'=>'Арабский','Armenian'=>'Армянский','Bengali'=>'Бенгальский','Braille'=>'шрифт Брайля','Custom validation error message'=>'Сообщение об ошибке проверки','Email Fields'=>'Поле электронной почты','Ethiopic'=>'Эфиопский','Georgian'=>'Грузинский','Greek'=>'Греческий','Hebrew'=>'Иврит','Hiragana'=>'Японский разг','Katakana'=>'Японский','Language Forbidden'=>'Запрещенные языки','Language Required'=>'Разрешенные языки','Latin'=>'Латинский','Maspik spam blacklist'=>'Maspik - черный список спама','Mongolian'=>'Монгольский','Options already added automatically from the API'=>'Параметры уже добавлены автоматически из API','Reset Log'=>'Сбросить журнал','Select'=>'Выбрать','Setting page'=>'Страница настроек','Spam Log'=>'Журнал спама','Syriac'=>'Сирийский','Text field'=>'Текстовое поле','Textarea Fields'=>'Поле текстовой области','Thai'=>'Тайский','There was an error adding this setting. Please try again. If this persists, shoot us an email.'=>'При добавлении этого параметра произошла ошибка. Пожалуйста, попробуйте еще раз. Если это не исчезнет, напишите нам по электронной почте.','This looks like spam. Try to rephrase, or contact us in an alternative way.'=>'Это похоже на спам. Попробуйте перефразировать или свяжитесь с нами другим способом.','Unknown language'=>'Неизвестный язык','Use this plugin with caution and only if you understand the risk, blacklisting some words can lead to the termination of valid leads.'=>'Используйте этот плагин с осторожностью и только в том случае, если вы понимаете риск, занесение некоторых слов в черный список может привести к прекращению действия действительных лидов.','Whenever a bot/person tries to spam your contact forms and MASPIK blocks the spam, you will see a new line below showing the details.<br>The log containing these details resides on your database and you can reset it at any time.<br>Resetting the log doesn’t change anything – it just removes the history.'=>'Всякий раз, когда бот/человек пытается спамить ваши контактные формы, а MASPIK блокирует спам, вы увидите новую строку ниже с подробностями.<br>Журнал, содержащий эти данные, находится в вашей базе данных, и вы можете сбросить его в любое время.< br>Сброс журнала ничего не меняет — он просто удаляет историю.']];
