<?php return array(
    'root' => array(
        'pretty_version' => '1.0.0+no-version-set',
        'version' => '1.0.0.0',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'reference' => NULL,
        'name' => '__root__',
        'dev' => true,
    ),
    'versions' => array(
        '__root__' => array(
            'pretty_version' => '1.0.0+no-version-set',
            'version' => '1.0.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'reference' => NULL,
            'dev_requirement' => false,
        ),
        'ideologix/dlm-php' => array(
            'pretty_version' => '1.1.0',
            'version' => '1.1.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ideologix/dlm-php',
            'aliases' => array(),
            'reference' => 'd28f6f08f7e68dc78f143b4966c2433965904741',
            'dev_requirement' => false,
        ),
        'ideologix/dlm-wp-simple-checker' => array(
            'pretty_version' => 'dev-master',
            'version' => 'dev-master',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ideologix/dlm-wp-simple-checker',
            'aliases' => array(
                0 => '9999999-dev',
            ),
            'reference' => '529dbf8c31619438ce730dbc11d4ecc8557d247a',
            'dev_requirement' => false,
        ),
    ),
);
